unit MFBO;

interface

{$L RS232.OBJ}
{$L MF_FP6.OBJ}

var
  _mfErrorL: integer;  (* pomocnicza zmienna przechowujaca kod bledu *)

const
  mfeOk          = 0; (* Wykonanie poprawne *)

  mfeImplementation =  1;
  mfeApplication    = -1;
  mfeFunction       = -2;
  mfeAssociation    = -3;
  mfeAccess         = -4;

  mfeHardware    = $0101; (* Bd sprztowy wewntrz czci fiskalnej *)
  mfeReserves1   = $0102; (* Wyczerpane zasoby nieodzyskiwalne *)
  mfeInitialize1 = $0103; (* Modu niezainicjowany *)

  mfeDisplay     = $0201; (* Brak komunikacji z wywietlaczem *)
  mfePrinter     = $0202; (* Bd komunikacji z drukark *)
  mfeBattery     = $0203; (* Niskie napicie baterii *)
  mfeReserves2   = $0204; (* Wyczerpane zasoby odzyskiwalne *)
  mfeFirmware    = $0205; (* Bd sprztowy wewntrz czci niefiskalnej *)
  mfeInitialize2 = $0206; (* Modu fiskalny nie zainicjowany przez serwisanta *)

  mfeAnyError     = $0301; (* Inny bd *)
  mfeNesting      = $0302; (* Niedopuszczalne zagniedenie funkcji *)
  mfeOutOfRange   = $0303; (* Przekroczenie zakresu *)
  mfeBadTaxRate   = $0304; (* Za stawka podatkowa *)
  mfeBadSellName  = $0305; (* Towar o podanej nazwie nie moe by sprzedany *)
  mfeBadDefName   = $0306; (* Towar o podanej nazwie nie moe by zdefiniowany *)
  mfeNoClkChng    = $0307; (* Przestawienie zegara niemoliwe *)
  mfeReserve2     = $0308; (* *)
  mfeShiftOpen    = $0309; (* Zmiana otwarta *)
  mfeShiftClose   = $030A; (* Zmiana zamknita *)
  mfeReceiptOpen  = $030B; (* Paragon w druku *)
  mfeReceiptClose = $030C; (* Paragon nie jest w druku *)
  mfeNoMoreShift  = $030D; (* Limit zmian wyczerpany *)
  mfeInvFormat    = $030E; (* Brak denominacji *)
  mfeHDDErr       = $030F; (* Bd komunikacji z dyskiem *)
  mfeOutOfPaper   = $0310; (* Brak papieru *)


(****************************************************************************)
(* 2. Funkcje informacyjne                                                  *)
(****************************************************************************)

(* 2.1. Odczyt czasu zegara wewnetrznego drukarki fiskalnej *)
function mfGetTime( var hour, minute: integer ): integer;
far;

(* 2.2. Odczyt daty zegara wewnetrznego drukarki fiskalnej *)
function mfGetDate( var year, month, day: integer ): integer;
far;

(* 2.3. Odczyt wersji drukarki fiskalnej *)
function mfGetVersion( var version, subVersion: integer ): integer;
far;

(* 2.4. Wspolczynnik wolnych zasobow *)
function mfGetCoefficient( var recCoefficient, unRecCoefficient: integer ): integer;
far;

(* 2.5. Odczyt numeru ostatniego paragonu *)
function mfGetLastTicketNo( var lastTicketNo: longint ): integer;
far;

(* 2.6. Odczyt stawek podatkowych *)
function mfGetTax( var taxA, taxB, taxC, taxD, taxE, taxF: integer ): integer;
far;


(****************************************************************************)
(* 3. Funkcje informacyjne stale                                            *)
(****************************************************************************)

(* 3.1. Odczyt maksymalniej liczby zmian w ciagu doby *)
function mfParMaxShiftNo( var maxShiftNo: integer ): integer;
far;

(* 3.2. Odczyt rodzaju biblioteki (niefiskalna/fiskalna) *)
function mfParFiscal( var flag: integer ): integer;
far;

(* 3.3. Odczyt wersji biblioteki *)
function mfParLibVersion( var version, subVersion: integer; var name: string ): integer;
far;

(* 3.4. Odczyt tresci komunikatu *)
function mfParMessage( code: integer; var groupMsg, detailMsg: string ): integer;
far;

(* 3.5. Odczyt parametrow danych o towarze *)
function mfParPLU( var maxCode  : longint;
                   var length   : integer;
                   var setOfChar: string ): integer; far;

(* 3.6. Odczyt parametrow dotyczacych formatu naglowka na paragonach *)
function mfParHeader( var flag, maxLines, length: integer;
                      var setOfChar: string ): integer;
far;

(* 3.7. Odczyt danych dotyczacych parametrow wydruku paragonu *)
function mfParTicket( var discountDecimalPoint, flag: integer ): integer;
far;


(****************************************************************************)
(* 4. Funkcje inicjujace, ustawiajace i definiujace                         *)
(****************************************************************************)

(* 4.1. Dopuszczenie aplikacji *)
function mfStart( ident: string; mfPortNo: integer ): integer;
far;


(* 4.2. Definicja stopki paragonu *)

(* a) SFI zwracajaca dane dotyczace formatu stopki drukowanej na paragonach *)
function mfParFooter( var maxLines, length: integer; var setOfChar: string ): integer;
far;

(* b) FP definiujaca stopke *)
function mfDefFooter( footer: string ): integer;
far;


(* 4.3. Definicja numeru kasy i kasjera oraz nazwy kasjera *)

(* a) SFI zwracajaca dopuszczalny zakres parametrow numeracji kasy i kasjera*)
(*    oraz nazwy kasjera *)
function mfParPOS( var maxCashNo, maxCashierNo: integer;
                   var lengthName: integer; var setOfChar: string ): integer;
far;

(* b) FP definiujaca numer kasy i kasjera oraz nazwe kasjera *)
function mfDefPOS( cashNo, cashierNo: integer; cashierName: string ): integer;
far;


(* 4.4. Ustawienie czasu zegara wewnetrznego drukarki fiskalnej *)

(* a) SFI sprawdzajaca czy ustawienie czasu w zegarze jest wykonalne *)
(*    (w danej chwili) *)
function mfParTime: integer;
far;

(* b) FP ustawiajaca czas zegara wewnetrznego drukarki fiskalnej *)
function mfDefTime( hour, minute: integer ): integer;
far;


(* 4.5. Ustawianie wewnetrznego licznika paragonow *)

(* a) SFI sprawdzajaca czy ustawienie licznika paragonow jest wykonalne *)
(*    (w danej chwili) *)
function mfParCounter: integer;
far;

(* b) FP ustawiajaca licznik paragonow *)
function mfDefCounter( var counter: longint ): integer;
far;

(* a) SFI odczytujaca napis i parametry *)
function mfParString( stringID: integer; var string_: string; var maxLen: integer ): integer;
far;

(* b) SFI redefiniujaca napis *)
function mfDefString( stringID: integer; string_: string ): integer;
far;


(****************************************************************************)
(* 5. Funkcje towarowe                                                      *)
(****************************************************************************)

(* 5.1.SFI zwracajace informacje o mozliwosci zaktualizowania bazy towarowej*)

(* a) SFI zwracajaca informacje o mozliwosci czesciowego zaktualizowania *)
(*    bazy towarowej *)
function mfParDefPLU: integer;
far;

(* b) SFI zwracajaca informacje o mozliwosci calkowitego zaktualizowania *)
(*      bazy towarowej *)
function mfParDefAllPLU: integer;
far;

(* 5.2. Rozpoczecie czesciowego ladowania towarow *)
function mfBeDefPLU: integer;
far;

(* 5.3. Rozpoczecie calkowitego ladowania towarow *)
function mfBeDefAllPLU: integer;
far;

(* 5.4. Zaladowanie jednego towaru *)
function mfDefPLU( no: longint; name: string; taxCode: char ): integer;
far;

(* 5.5. Zakonczenie ladowania towarow *)
function mfEndDefPLU: integer;
far;


(****************************************************************************)
(* 6. Funkcje obslugujace paragon fiskalny                                  *)
(****************************************************************************)

(* 6.1. Rozpoczecie zmiany *)
function mfBeginShift( header: string ): integer;
far;

(* 6.2. Rozpoczecie wydruku paragonu *)
function mfBeginTicket( total: longint ): integer;
far;

(* 6.3. Wydruk linii paragonu *)
function mfLineTicket( no: longint; name: string; taxCode: char;
                       unitStr: string;
                       price, quantity, value: longint ): integer;
far;

(* 6.4. Uniewaznienie linii paragonu *)
function mfStornoLineTicket( no: longint; name: string; taxCode: char;
                             unitStr : string;
                             price, quantity, value: longint ): integer;
far;

(* 6.5. Uniewaznienie paragonu *)
function mfStornoTicket: integer;
far;

(* 6.6. Zakonczenie wydruku paragonu *)
function mfEndTicket( percentDiscount: integer; valueDiscount: longint;
                      transactionNo: longint;
                      payment1: longint; paymStr1: string;
                      payment2: longint; paymStr2: string;
                      payment3: longint; paymStr3: string;
		      change: longint; changeStr: string;
		      pawn: longint; pawnStr: string;
		      tableStr: string;
		      custStr: string ): integer;
far;

(* 6.7. Zamkniecie zmiany *)
function mfShiftEnd: integer;
far;

(* 6.8. Wydruk linii paragonu aptecznego *)
function mfAptLineTicket( no: longint; name: string; taxCode: char;
                          unitStr: string;
                          price, quantity, value, charge: longint;
                          payType, recType: string; refundation: longint ): integer;
far;

(****************************************************************************)
(* 7. Funkcje obslugujace raporty fiskalne                                  *)
(****************************************************************************)

(* 7.1. Rozpoczecie wydruku listy towarow danej stawki podatkowej *)

(* a) SFI sprawdzajaca czy FP jest wykonalna *)
function mfParPrBeTaxCode: integer;
far;

(* b) FP rozpoczynajaca wydruk towarow z okreslonej stawki podatkowej *)
function mfPrBeTaxCode( taxCode: char ): integer;
far;


(* 7.2. Rozpoczecie wydruku listy towarow wedlug numeru porzadkowego *)

(* a) SFI sprawdzajaca czy FP jest wykonalna *)
function mfParPrBeItemNo: integer;
far;

(* b)FP rozpoczynajaca wydruk towarow z okreslonego przedzialu kodow towarow*)
function mfPrBeItemNo( var startItem, stopItem: longint ): integer;
far;


(* 7.3. Wydruk pojedynczego towaru *)
function mfPrItem( no: longint; name: string; taxCode: char ): integer;
far;

(* 7.4. Zakonczenie wydruku listy towarow *)
function mfPrEnd: integer;
far;

(* 7.5. Raport okresowy szczegolowy *)
function mfPrDetailReport( startYear, startMonth, startDay: integer;
                           stopYear,  stopMonth,  stopDay : integer ): integer;
far;

(* 7.6. Raport okresowy sumaryczny *)
function mfPrGlobalReport( startYear, startMonth, startDay: integer;
                           stopYear,  stopMonth,  stopDay : integer ): integer;
far;

(* 7.7. Wydruk stanu modulu fiskalnego *)

(* a) SFI sprawdzajaca czy FP jest wykonalna *)
function mfParPrState: integer;
far;

(* b) FP drukujaca stan modulu fiskalnego *)
function mfPrState: integer;
far;


(* 7.8. Wydruk listy zmian towarow *)

(* a) SFI sprawdzajaca czy FP jest wykonalna *)
function mfParPrChangeItem: integer;
far;

(* b) FP drukujaca wydruk listy zmian towarow *)
function mfPrChangeItem: integer;
far;


(****************************************************************************)
(* 8. Funkcje obslugujace paragon niefiskalny                               *)
(****************************************************************************)

(* 8.1. Wydruk kwitu wplaty do kasy KP *)

(* a) SFI okreslajaca czy skojarzona FP jest dostepna w danej DF *)
function mfParPayIn: integer;
far;

(* b) FP drukujaca dokument *)
function mfPrPayIn( no, personName, payInName, amount: string ): integer;
far;


(* 8.2. Wydruk kwitu wyplaty KW *)

(* a) SFI okreslajaca czy skojarzona FP jest dostepna w danej DF *)
function mfParPayOut: integer;
far;

(* b) FP drukujaca dokument *)
function mfPrPayOut( no, personName, payOutName, amount: string ): integer;
far;


(* 8.3. Wydruk kwitu (bonu) zamowienia w kuchni *)

(* a) SFI okreslajaca czy skojarzona FP jest dostepna w danej DF *)
function mfParOrder: integer;
far;

(* b) FP rozpoczynajaca wydruk *)
function mfBgOrder( title, name: string ): integer;
far;

(* c) FP drukujaca jedna linie dokumentu *)
function mfLineOrder( name, modifier, quant: string ): integer;
far;

(* d) FP konczaca wydruk *)
function mfEndOrder: integer;
far;


(* 8.4. Wydruk dokumentu zwrotu towarow *)

(* a) SFI okreslajaca czy skojarzona FP jest dostepna w danej DF *)
function mfParReturn: integer;
far;

(* b) FP rozpoczynajaca wydruk *)
function mfBgReturn( no, personName, value: string ): integer;
far;

(* c) FP drukujaca jedna linie dokumentu *)
function mfLineReturn( name, quant, total: string ): integer;
far;

(* d) FP konczaca wydruk *)
function mfEndReturn: integer;
far;


(* 8.5. Wydruk raportu rozliczenia kasjera *)

(* a) SFI okreslajaca czy skojarzona FP jest dostepna w danej DF *)
function mfParCashierReport: integer;
far;

(* b) FP rozpoczynajaca wydruk *)
function mfBgCashierReport( no, name: string ): integer;
far;

(* c) FP drukujaca jedna linie dokumentu *)
function mfLineCashierReport( typeNo: integer;
                              name, counted, cash, difference: string ): integer;
far;

(* d) FP konczaca wydruk *)
function mfEndCashierReport: integer;
far;


(* 8.6. Wydruk raportu rozliczenia zmiany *)

(* a) SFI okreslajaca czy skojarzona FP jest dostepna w danej DF *)
function mfParShiftReport: integer; far;

(* b) FP rozpoczynajaca wydruk *)
function mfBgShiftReport( no, startDate, endDate, personName: string ): integer;
far;

(* c) FP drukujaca jedna linie dokumentu *)
function mfLineShiftReport( typeNo: integer;
                            name, counted, cash, difference: string ): integer;
far;

(* d) FP konczaca wydruk *)
function mfEndShiftReport: integer;
far;


(* 8.7. Uniewaznienie dokumentu *)
function mfPrVoid: integer;
far;

(* 8.8. Wydruk kwitu karty platniczej *)
(* a) *)
function mfParVISA: integer;
far;

(* b) *)
function mfPrVISA( language, signature: integer;
                   date,
		   transactionNo, ticketNo, salesPointNo,
                   TID, UID,
                   PosID, cashierName,
                   cardName, cardNumber, expiryDate,
                   authorizationCode,
                   salesAmount, returnAmount,
                   salesSays1, salesSays234: string ): integer;
far;

(****************************************************************************)
(* 9. Funkcje obslugujace szuflade                                          *)
(****************************************************************************)

(* 9.1. Definicja parametrow (rodzaju) szuflady *)

(* a) SFI zwracajaca nazwy zaimplementowanych szuflad *)
function mfParDrawer( item : integer; var name : string; var maxNo: integer ): integer;
far;

(* b) FP definiujaca typ szuflady *)
function mfDefDrawer( item, portNo: integer ): integer;
far;

(* 9.2. Otwarcie szuflady *)
function mfDrawerOpen( no: integer ): integer;
far;

(* 9.3. Sprawdzenie stanu szuflady (otwarta/zamknieta) *)
function mfDrawerIsOpen( no  : integer; var flag: integer ): integer;
far;


(****************************************************************************)
(* 10. Funkcje obslugujace wyswietlacz                                      *)
(****************************************************************************)

(* 10.1. Definicja parametrow (typow) wyswietlacza *)

(* a) SFI zwracajaca parametry zaimplementowanych w danej wersji biblioteki *)
(*   typow wyswietlaczy fiskalnych (dotyczy DF) lub niestandardowych        *)
(*   (dotyczy DNF) *)
function mfParFiscDisp(     item       : integer;
                        var name       : string;
                        var column     : integer;
                        var row        : integer;
                        var setOfChar  : string;
                        var numericFlag: integer;
                        var pointFlag  : integer ): integer;
far;

(* b) FP definiujaca wyswietlacz dostepny z listy (fiskalny lub niestand. *)
function mfDefFiscalDisp( item, portNo: integer ): integer;
far;

(* c) FP definiujaca wyswietlacz niedostepny z listy (standardowy-niefisk/) *)
function mfDefNFiscalDisp( portNo       : integer;
                           row, column  : integer;
                           setOfChar    : string;
                           begin0       : string;
                           begin1, end1 : string;
                           begin2, end2 : string;
                           begin3, end3 : string;
                           numericFlag, pointFlag     : integer;
                           sBouds, sParity, sStopBits : integer;
                           codePage    : integer ): integer;
far;


(* 10.2. Wylaczenie/zalaczenie automatycznej obslugi wyswietlacza *)
(* function mfDispStop( flag: integer ): integer; *)
(* far; *)

(* 10.3. Wyswietlenie POZYCJI SPRZEDAZY *)
function mfDispTicketLine( name: string;
                           price, quantity, value: longint ): integer;
far;

(* 10.4. Wyswietlenie SUMY *)
function mfDispSum( sumName : string; sumValue: longint ): integer;
far;

(* 10.5. Wyswietlenie PODSUMOWANIA *)
function mfDispSummary( payName      : string; payValue      : longint;
                        remainderName: string; remainderValue: longint ): integer;
far;

(* 10.6. Wyswietlenie LOGO UZYTKOWNIKA *)
function mfDispConsumerLOGO( lineLOGO1, lineLOGO2: string ): integer;
far;


(****************************************************************************)
(* 11. Funkcje statusowe                                                    *)
(****************************************************************************)

(* 11.1. Tryb szkoleniowy / fiskalny *)
function mfStatMode( var flag: integer ): integer;
far;

(* 11.2. Waluta przed denominacja / po denominacji *)
function mfStatDenom( var flag: integer ): integer;
far;

(* 11.3. Zmiana fiskalna zamknieta / otwarta. *)
function mfStatShift( var flag: integer ): integer;
far;

(* 11.4. Paragon zamkniety / otwarty. *)
function mfStatReceipt( var flag: integer ): integer;
far;

(* 11.5. Dokument nie drukowany / drukowany. *)
function mfStatDocument( var flag: integer ): integer;
far;

(* 11.6. Brak papieru *)
function mfStatNoPaper( var flag: integer ): integer;
far;


(****************************************************************************)
(* 12. Funkcje obslugujace apteczne paragony niefiskalne                    *)
(****************************************************************************)

(* 12.1. Wycena leku *)

(* a) *)
function mfWycena1( numerStacji: integer;
                    nazwa, dawka, opakowanie: string;
                    ilosc, cena, wartosc, oplata: longint;
                    PTUstawka: string; PTUwartosc: longint ): integer;
far;

(* b) *)
function mfWycena2( iloscLekospisowa, limit, ponadLimit: longint;
                    oplataPodstawowa, doplata100, refundacja: longint;
                    pacjent, lekarz : string;
                    refundator, wojewodztwo: string ): integer;
far;

(* c) *)
function mfWycena3( platne, recepta: string;
                    refundacja: integer; wydal: string;
                    kasa: integer; transakcja: longint ): integer;
far;

(* d) *)
function mfAnulujWycene: integer;
far;

(* 12.2. Wycena leku - kupon RUM *)
(* a) *)
function mfRUMStart( numerStacji: integer; recepta, kupon: string ): integer;
far;

(* b) *)
function mfRUMLinia( tekst, opakowanie: string;
                     ilosc, cena, stawka, podatek, wartosc: string;
                     platne, odplatnosc, refundacja, recepta: string ): integer;
far;

(* c) *)
function mfRUMStop( odplatnosc, refundacja, slownie, pacjent, lekarz: string;
                    refundator, wojewodztwo, wydal, kasa: string ): integer;
far;

(* 12.3. Wycena leku robionego *)
function mfLekStart( numerStacji: integer;
                     recepta, odplatnosc, nrRecepty: string ): integer;
far;

function mfLekLinia( nazwa, ilosc, wartosc: string ): integer;
far;

function mfLekStop( wartoscBrutto, wartoscNetto, podatek: string;
                    taksaLaborum, doZaplaty, starychZlotych: string;
                    pacjent, lekarz, refundator, wojewodztwo: string;
                    wydal, przyjal, wycenil, kasa: string;
                    terminOdbioru, numerLeku: string ): integer;
far;

(* 12.4 Wydruk dowolnej linii *)
function mfDrukuj( formularz, wiersz, argument: string ): integer;
far;


(****************************************************************************)
(* 13. Funkcje obslugujace faktury                                          *)
(****************************************************************************)

(* 13.1 Rozpoczecie faktury *)
function mfFaktStart( wysuw, typ, napis: integer;
                      linii, typRamki: integer;
                      nrFakt, nrOrg, miasto,
                      dataWyst, dataSprz,
                      nrParag, nrKasy,
                      sprzedawca, sprzedawcaNIP,
                      nabywca, nabywcaNIP,
                      transport, bank, platnosc, termin: string;
                      paperInTimeout, paperOutTimeout: longint ): integer;
far;

(* 13.2 Wydruk linii faktury *)
function mfFaktLinia( nazwa, sww, jm, ilosc, cena, wartNetto, wartBrutto,
                      stawka, wartPTU, wartOpl: string ): integer;
far;

(* 13.3 Zakonczenie faktury *)
function mfFaktKoniec( slownie, doZapl, nazwaSprz, nazwaOdb, dopiski,
                       wartNettoA, wartBruttoA, stawkaA, wartPTUA,
                       wartNettoB, wartBruttoB, stawkaB, wartPTUB,
                       wartNettoC, wartBruttoC, stawkaC, wartPTUC,
                       wartNettoD, wartBruttoD, stawkaD, wartPTUD,
                       wartNettoE, wartBruttoE, stawkaE, wartPTUE,
                       wartNettoF, wartBruttoF, stawkaF, wartPTUF,
                       wartZwol,
                       wartNettoSum, wartBruttoSum, wartPTUSum: string ): integer;
far;

(* 13.4 Anulacja faktury *)
function mfAnulujFakture: integer;
far;

function mfFaktPaper(var paperIn, paperOut: integer): integer;
far;

(* Dodatek A - Komunikacja bezposrednia z DF *)
function mfAnyCommand( outputL: integer; output: string;
                       inputL: integer; var input: string;
                       var resultL: integer; timeOut: longint ): integer;
far;

(* Odczyt kodu bledu *)
function mfError: integer;
far;


(****************************************************************************)
(*                      I M P L E M E N T A C J A                           *)
(****************************************************************************)
implementation

(****************************************************************************)
(* 2. Funkcje informacyjne                                                  *)
(****************************************************************************)

(* 2.1. Odczyt czasu zegara wewnetrznego drukarki fiskalnej *)
function mfGetTime( var hour, minute: integer ): integer;
external;

(* 2.2. Odczyt daty zegara wewnetrznego drukarki fiskalnej *)
function mfGetDate( var year, month, day: integer ): integer;
external;

(* 2.3. Odczyt wersji drukarki fiskalnej *)
function mfGetVersion( var version, subVersion: integer ): integer;
external;

(* 2.4. Wspolczynnik wolnych zasobow *)
function mfGetCoefficient( var recCoefficient, unRecCoefficient: integer ): integer;
external;

(* 2.5. Odczyt numeru ostatniego paragonu *)
function mfGetLastTicketNo( var lastTicketNo: longint ): integer;
external;

(* 2.6. Odczyt stawek podatkowych *)
function mfGetTax( var taxA, taxB, taxC, taxD, taxE, taxF: integer ): integer;
external;


(****************************************************************************)
(* 3. Funkcje informacyjne stale                                            *)
(****************************************************************************)

(* 3.1. Odczyt maksymalniej liczby zmian w ciagu doby *)
function mfParMaxShiftNo( var maxShiftNo: integer ): integer;
external;

(* 3.2. Odczyt rodzaju biblioteki (niefiskalna/fiskalna) *)
function mfParFiscal( var flag: integer ): integer;
external;

(* 3.3. Odczyt wersji biblioteki *)
function mfParLibVersion( var version, subVersion: integer; var name: string ): integer;
external;

(* 3.4. Odczyt tresci komunikatu *)
function mfParMessage( code: integer; var groupMsg, detailMsg: string ): integer;
external;

(* 3.5. Odczyt parametrow danych o towarze *)
function mfParPLU( var maxCode  : longint;
                   var length   : integer;
                   var setOfChar: string ): integer; external;

(* 3.6. Odczyt parametrow dotyczacych formatu naglowka na paragonach *)
function mfParHeader( var flag, maxLines, length: integer;
                      var setOfChar: string ): integer;
external;

(* 3.7. Odczyt danych dotyczacych parametrow wydruku paragonu *)
function mfParTicket( var discountDecimalPoint, flag: integer ): integer;
external;


(****************************************************************************)
(* 4. Funkcje inicjujace, ustawiajace i definiujace                         *)
(****************************************************************************)

(* 4.1. Dopuszczenie aplikacji *)
function mfStart( ident: string; mfPortNo: integer ): integer;
external;


(* 4.2. Definicja stopki paragonu *)

(* a) SFI zwracajaca dane dotyczace formatu stopki drukowanej na paragonach *)
function mfParFooter( var maxLines, length: integer; var setOfChar: string ): integer;
external;

(* b) FP definiujaca stopke *)
function mfDefFooter( footer: string ): integer;
external;


(* 4.3. Definicja numeru kasy i kasjera oraz nazwy kasjera *)

(* a) SFI zwracajaca dopuszczalny zakres parametrow numeracji kasy i kasjera*)
(*    oraz nazwy kasjera *)
function mfParPOS( var maxCashNo, maxCashierNo: integer;
                   var lengthName: integer; var setOfChar: string ): integer;
external;

(* b) FP definiujaca numer kasy i kasjera oraz nazwe kasjera *)
function mfDefPOS( cashNo, cashierNo: integer; cashierName: string ): integer;
external;


(* 4.4. Ustawienie czasu zegara wewnetrznego drukarki fiskalnej *)

(* a) SFI sprawdzajaca czy ustawienie czasu w zegarze jest wykonalne *)
(*    (w danej chwili) *)
function mfParTime: integer;
external;

(* b) FP ustawiajaca czas zegara wewnetrznego drukarki fiskalnej *)
function mfDefTime( hour, minute: integer ): integer;
external;


(* 4.5. Ustawianie wewnetrznego licznika paragonow *)

(* a) SFI sprawdzajaca czy ustawienie licznika paragonow jest wykonalne *)
(*    (w danej chwili) *)
function mfParCounter: integer;
external;

(* b) FP ustawiajaca licznik paragonow *)
function mfDefCounter( var counter: longint ): integer;
external;

(* a) SFI odczytujaca napis i parametry *)
function mfParString( stringID: integer; var string_: string; var maxLen: integer ): integer;
external;

(* b) SFI redefiniujaca napis *)
function mfDefString( stringID: integer; string_: string ): integer;
external;


(****************************************************************************)
(* 5. Funkcje towarowe                                                      *)
(****************************************************************************)

(* 5.1.SFI zwracajace informacje o mozliwosci zaktualizowania bazy towarowej*)

(* a) SFI zwracajaca informacje o mozliwosci czesciowego zaktualizowania *)
(*    bazy towarowej *)
function mfParDefPLU: integer;
external;

(* b) SFI zwracajaca informacje o mozliwosci calkowitego zaktualizowania *)
(*      bazy towarowej *)
function mfParDefAllPLU: integer;
external;

(* 5.2. Rozpoczecie czesciowego ladowania towarow *)
function mfBeDefPLU: integer;
external;

(* 5.3. Rozpoczecie calkowitego ladowania towarow *)
function mfBeDefAllPLU: integer;
external;

(* 5.4. Zaladowanie jednego towaru *)
function mfDefPLU( no: longint; name: string; taxCode: char ): integer;
external;

(* 5.5. Zakonczenie ladowania towarow *)
function mfEndDefPLU: integer;
external;


(****************************************************************************)
(* 6. Funkcje obslugujace paragon fiskalny                                  *)
(****************************************************************************)

(* 6.1. Rozpoczecie zmiany *)
function mfBeginShift( header: string ): integer;
external;

(* 6.2. Rozpoczecie wydruku paragonu *)
function mfBeginTicket( total: longint ): integer;
external;

(* 6.3. Wydruk linii paragonu *)
function mfLineTicket( no: longint; name: string; taxCode: char;
                       unitStr: string;
                       price, quantity, value: longint ): integer;
external;

(* 6.4. Uniewaznienie linii paragonu *)
function mfStornoLineTicket( no: longint; name: string; taxCode: char;
                             unitStr : string;
                             price, quantity, value: longint ): integer;
external;

(* 6.5. Uniewaznienie paragonu *)
function mfStornoTicket: integer;
external;

(* 6.6. Zakonczenie wydruku paragonu *)
function mfEndTicket( percentDiscount: integer; valueDiscount: longint;
                      transactionNo: longint;
                      payment1: longint; paymStr1: string;
                      payment2: longint; paymStr2: string;
                      payment3: longint; paymStr3: string;
		      change: longint; changeStr: string;
		      pawn: longint; pawnStr: string;
		      tableStr: string;
		      custStr: string ): integer;
external;

(* 6.7. Zamkniecie zmiany *)
function mfShiftEnd: integer;
external;

(* 6.8. Wydruk linii paragonu aptecznego *)
function mfAptLineTicket( no: longint; name: string; taxCode: char;
                          unitStr: string;
                          price, quantity, value, charge: longint;
                          payType, recType: string; refundation: longint ): integer;
external;

(* 6.9. Rozszerzony wydruk linii *)

(****************************************************************************)
(* 7. Funkcje obslugujace raporty fiskalne                                  *)
(****************************************************************************)

(* 7.1. Rozpoczecie wydruku listy towarow danej stawki podatkowej *)

(* a) SFI sprawdzajaca czy FP jest wykonalna *)
function mfParPrBeTaxCode: integer;
external;

(* b) FP rozpoczynajaca wydruk towarow z okreslonej stawki podatkowej *)
function mfPrBeTaxCode( taxCode: char ): integer;
external;


(* 7.2. Rozpoczecie wydruku listy towarow wedlug numeru porzadkowego *)

(* a) SFI sprawdzajaca czy FP jest wykonalna *)
function mfParPrBeItemNo: integer;
external;

(* b)FP rozpoczynajaca wydruk towarow z okreslonego przedzialu kodow towarow*)
function mfPrBeItemNo( var startItem, stopItem: longint ): integer;
external;


(* 7.3. Wydruk pojedynczego towaru *)
function mfPrItem( no: longint; name: string; taxCode: char ): integer;
external;

(* 7.4. Zakonczenie wydruku listy towarow *)
function mfPrEnd: integer;
external;

(* 7.5. Raport okresowy szczegolowy *)
function mfPrDetailReport( startYear, startMonth, startDay: integer;
                           stopYear,  stopMonth,  stopDay : integer ): integer;
external;

(* 7.6. Raport okresowy sumaryczny *)
function mfPrGlobalReport( startYear, startMonth, startDay: integer;
                           stopYear,  stopMonth,  stopDay : integer ): integer;
external;

(* 7.7. Wydruk stanu modulu fiskalnego *)

(* a) SFI sprawdzajaca czy FP jest wykonalna *)
function mfParPrState: integer;
external;

(* b) FP drukujaca stan modulu fiskalnego *)
function mfPrState: integer;
external;


(* 7.8. Wydruk listy zmian towarow *)

(* a) SFI sprawdzajaca czy FP jest wykonalna *)
function mfParPrChangeItem: integer;
external;

(* b) FP drukujaca wydruk listy zmian towarow *)
function mfPrChangeItem: integer;
external;


(****************************************************************************)
(* 8. Funkcje obslugujace paragon niefiskalny                               *)
(****************************************************************************)

(* 8.1. Wydruk kwitu wplaty do kasy KP *)

(* a) SFI okreslajaca czy skojarzona FP jest dostepna w danej DF *)
function mfParPayIn: integer;
external;

(* b) FP drukujaca dokument *)
function mfPrPayIn( no, personName, payInName, amount: string ): integer;
external;


(* 8.2. Wydruk kwitu wyplaty KW *)

(* a) SFI okreslajaca czy skojarzona FP jest dostepna w danej DF *)
function mfParPayOut: integer;
external;

(* b) FP drukujaca dokument *)
function mfPrPayOut( no, personName, payOutName, amount: string ): integer;
external;


(* 8.3. Wydruk kwitu (bonu) zamowienia w kuchni *)

(* a) SFI okreslajaca czy skojarzona FP jest dostepna w danej DF *)
function mfParOrder: integer;
external;

(* b) FP rozpoczynajaca wydruk *)
function mfBgOrder( title, name: string ): integer;
external;

(* c) FP drukujaca jedna linie dokumentu *)
function mfLineOrder( name, modifier, quant: string ): integer;
external;

(* d) FP konczaca wydruk *)
function mfEndOrder: integer;
external;


(* 8.4. Wydruk dokumentu zwrotu towarow *)

(* a) SFI okreslajaca czy skojarzona FP jest dostepna w danej DF *)
function mfParReturn: integer;
external;

(* b) FP rozpoczynajaca wydruk *)
function mfBgReturn( no, personName, value: string ): integer;
external;

(* c) FP drukujaca jedna linie dokumentu *)
function mfLineReturn( name, quant, total: string ): integer;
external;

(* d) FP konczaca wydruk *)
function mfEndReturn: integer;
external;


(* 8.5. Wydruk raportu rozliczenia kasjera *)

(* a) SFI okreslajaca czy skojarzona FP jest dostepna w danej DF *)
function mfParCashierReport: integer;
external;

(* b) FP rozpoczynajaca wydruk *)
function mfBgCashierReport( no, name: string ): integer;
external;

(* c) FP drukujaca jedna linie dokumentu *)
function mfLineCashierReport( typeNo: integer;
                              name, counted, cash, difference: string ): integer;
external;

(* d) FP konczaca wydruk *)
function mfEndCashierReport: integer;
external;


(* 8.6. Wydruk raportu rozliczenia zmiany *)

(* a) SFI okreslajaca czy skojarzona FP jest dostepna w danej DF *)
function mfParShiftReport: integer; external;

(* b) FP rozpoczynajaca wydruk *)
function mfBgShiftReport( no, startDate, endDate, personName: string ): integer;
external;

(* c) FP drukujaca jedna linie dokumentu *)
function mfLineShiftReport( typeNo: integer;
                            name, counted, cash, difference: string ): integer;
external;

(* d) FP konczaca wydruk *)
function mfEndShiftReport: integer;
external;


(* 8.7. Uniewaznienie dokumentu *)
function mfPrVoid: integer;
external;

(* 8.8. Wydruk kwitu karty platniczej *)
(* a) *)
function mfParVISA: integer;
external;

(* b) *)
function mfPrVISA( language, signature: integer;
                   date,
		   transactionNo, ticketNo, salesPointNo,
                   TID, UID,
                   PosID, cashierName,
                   cardName, cardNumber, expiryDate,
                   authorizationCode,
                   salesAmount, returnAmount,
                   salesSays1, salesSays234: string ): integer;
external;


(****************************************************************************)
(* 9. Funkcje obslugujace szuflade                                          *)
(****************************************************************************)

(* 9.1. Definicja parametrow (rodzaju) szuflady *)

(* a) SFI zwracajaca nazwy zaimplementowanych szuflad *)
function mfParDrawer( item : integer; var name : string; var maxNo: integer ): integer;
external;

(* b) FP definiujaca typ szuflady *)
function mfDefDrawer( item, portNo: integer ): integer;
external;

(* 9.2. Otwarcie szuflady *)
function mfDrawerOpen( no: integer ): integer;
external;

(* 9.3. Sprawdzenie stanu szuflady (otwarta/zamknieta) *)
function mfDrawerIsOpen( no  : integer; var flag: integer ): integer;
external;


(****************************************************************************)
(* 10. Funkcje obslugujace wyswietlacz                                      *)
(****************************************************************************)

(* 10.1. Definicja parametrow (typow) wyswietlacza *)

(* a) SFI zwracajaca parametry zaimplementowanych w danej wersji biblioteki *)
(*   typow wyswietlaczy fiskalnych (dotyczy DF) lub niestandardowych        *)
(*   (dotyczy DNF) *)
function mfParFiscDisp(     item       : integer;
                        var name       : string;
                        var column     : integer;
                        var row        : integer;
                        var setOfChar  : string;
                        var numericFlag: integer;
                        var pointFlag  : integer ): integer;
external;

(* b) FP definiujaca wyswietlacz dostepny z listy (fiskalny lub niestand. *)
function mfDefFiscalDisp( item, portNo: integer ): integer;
external;

(* c) FP definiujaca wyswietlacz niedostepny z listy (standardowy-niefisk/) *)
function mfDefNFiscalDisp( portNo       : integer;
                           row, column  : integer;
                           setOfChar    : string;
                           begin0       : string;
                           begin1, end1 : string;
                           begin2, end2 : string;
                           begin3, end3 : string;
                           numericFlag, pointFlag     : integer;
                           sBouds, sParity, sStopBits : integer;
                           codePage    : integer ): integer;
external;


(* 10.2. Wylaczenie/zalaczenie automatycznej obslugi wyswietlacza *)
(* function mfDispStop( flag: integer ): integer; *)
(* external; *)

(* 10.3. Wyswietlenie POZYCJI SPRZEDAZY *)
function mfDispTicketLine( name: string;
                           price, quantity, value: longint ): integer;
external;

(* 10.4. Wyswietlenie SUMY *)
function mfDispSum( sumName : string; sumValue: longint ): integer;
external;

(* 10.5. Wyswietlenie PODSUMOWANIA *)
function mfDispSummary( payName      : string; payValue      : longint;
                        remainderName: string; remainderValue: longint ): integer;
external;

(* 10.6. Wyswietlenie LOGO UZYTKOWNIKA *)
function mfDispConsumerLOGO( lineLOGO1, lineLOGO2: string ): integer;
external;


(****************************************************************************)
(* 11. Funkcje statusowe                                                    *)
(****************************************************************************)

(* 11.1. Tryb szkoleniowy / fiskalny *)
function mfStatMode( var flag: integer ): integer;
external;

(* 11.2. Waluta przed denominacja / po denominacji *)
function mfStatDenom( var flag: integer ): integer;
external;

(* 11.3. Zmiana fiskalna zamknieta / otwarta. *)
function mfStatShift( var flag: integer ): integer;
external;

(* 11.4. Paragon zamkniety / otwarty. *)
function mfStatReceipt( var flag: integer ): integer;
external;

(* 11.5. Dokument nie drukowany / drukowany. *)
function mfStatDocument( var flag: integer ): integer;
external;

(* 11.6. Brak papieru *)
function mfStatNoPaper( var flag: integer ): integer;
external;


(****************************************************************************)
(* 12. Funkcje obslugujace apteczne paragony niefiskalne                    *)
(****************************************************************************)

(* 12.1. Wycena leku *)

(* a) *)
function mfWycena1( numerStacji: integer;
                    nazwa, dawka, opakowanie: string;
                    ilosc, cena, wartosc, oplata: longint;
                    PTUstawka: string; PTUwartosc: longint ): integer;
external;

(* b) *)
function mfWycena2( iloscLekospisowa, limit, ponadLimit: longint;
                    oplataPodstawowa, doplata100, refundacja: longint;
                    pacjent, lekarz : string;
                    refundator, wojewodztwo: string ): integer;
external;

(* c) *)
function mfWycena3( platne, recepta: string;
                    refundacja: integer; wydal: string;
                    kasa: integer; transakcja: longint ): integer;
external;

(* d) *)
function mfAnulujWycene: integer;
external;

(* 12.2. Wycena leku - kupon RUM *)
(* a) *)
function mfRUMStart( numerStacji: integer; recepta, kupon: string ): integer;
external;

(* b) *)
function mfRUMLinia( tekst, opakowanie: string;
                     ilosc, cena, stawka, podatek, wartosc: string;
                     platne, odplatnosc, refundacja, recepta: string ): integer;
external;

(* c) *)
function mfRUMStop( odplatnosc, refundacja, slownie, pacjent, lekarz: string;
                    refundator, wojewodztwo, wydal, kasa: string ): integer;
external;

(* 12.3. Wycena leku robionego *)
function mfLekStart( numerStacji: integer;
                     recepta, odplatnosc, nrRecepty: string ): integer;
external;

function mfLekLinia( nazwa, ilosc, wartosc: string ): integer;
external;

function mfLekStop( wartoscBrutto, wartoscNetto, podatek: string;
                    taksaLaborum, doZaplaty, starychZlotych: string;
                    pacjent, lekarz, refundator, wojewodztwo: string;
                    wydal, przyjal, wycenil, kasa: string;
                    terminOdbioru, numerLeku: string ): integer;
external;

(* 12.4 Wydruk dowolnej linii *)
function mfDrukuj( formularz, wiersz, argument: string ): integer;
external;


(****************************************************************************)
(* 13. Funkcje obslugujace faktury                                          *)
(****************************************************************************)

(* 13.1 Rozpoczecie faktury *)
function mfFaktStart( wysuw, typ, napis: integer;
                      linii, typRamki: integer;
                      nrFakt, nrOrg, miasto,
                      dataWyst, dataSprz,
                      nrParag, nrKasy,
                      sprzedawca, sprzedawcaNIP,
                      nabywca, nabywcaNIP,
                      transport, bank, platnosc, termin: string;
                      paperInTimeout, paperOutTimeout: longint ): integer;
external;

(* 13.2 Wydruk linii faktury *)
function mfFaktLinia( nazwa, sww, jm, ilosc, cena, wartNetto, wartBrutto,
                      stawka, wartPTU, wartOpl: string ): integer;
external;

(* 13.3 Zakonczenie faktury *)
function mfFaktKoniec( slownie, doZapl, nazwaSprz, nazwaOdb, dopiski,
                       wartNettoA, wartBruttoA, stawkaA, wartPTUA,
                       wartNettoB, wartBruttoB, stawkaB, wartPTUB,
                       wartNettoC, wartBruttoC, stawkaC, wartPTUC,
                       wartNettoD, wartBruttoD, stawkaD, wartPTUD,
                       wartNettoE, wartBruttoE, stawkaE, wartPTUE,
                       wartNettoF, wartBruttoF, stawkaF, wartPTUF,
                       wartZwol,
                       wartNettoSum, wartBruttoSum, wartPTUSum: string ): integer;
external;

(* 13.4 Anulacja faktury *)
function mfAnulujFakture: integer;
external;

function mfFaktPaper(var paperIn, paperOut: integer): integer;
external;

(* Dodatek A - Komunikacja bezposrednia z DF *)
function mfAnyCommand( outputL: integer; output: string;
                       inputL: integer; var input: string;
                       var resultL: integer; timeOut: longint ): integer;
external;

(* Odczyt kodu bledu *)
function mfError: integer;
external;

end.
